/** Copyright AZS Services 2002-2004 http://www.a2zss.com */
package com.a2zss.ISO8583.samples;

import com.a2zss.ISO8583.*;

public class isosample {
	
	
	public static void main(String[] args) {	

	Config conf=new Config();
	ISO8583II isosdk=new ISO8583II(conf);
	isosdk.setDebuglevel(3);
	isosdk.setOutput(System.out);
	boolean debug=true;
		
	int n=10; // number of cycles to test performance
	try { if (args!=null) n=Integer.valueOf(args[0]).intValue();
	    } catch (Exception exl) { n=10;}
	
	try { if (args!=null && args.length>1 && "nodebug".equals(args[1])) 
		  {	isosdk.setDebuglevel(0);
		  	isosdk.setOutput(null);
			debug=false;
		  }
	    } catch (Exception exl) {}


	long start=System.currentTimeMillis();
	for(int j=0; j<n; j++)
	{

	// building iso message as follows:
	Message message=new Message(); // this an empty message
	//5.1.2.2 Credit Card Financial Request Format (0100/0200)
	
	 // the new optional header field Identifier
	 ISOField fh_ident=new ISOField(ISOField.FH_IDENT, "ML", conf);
	 message.putISOField(fh_ident);
	 
	 // the new optional headerfield Identifier DPC Number
	 ISOField fh_dcp=new ISOField(ISOField.FH_DCP, "1234", conf);
	 message.putISOField(fh_dcp);
	 	  
	 ISOField mti=new ISOField(ISOField.F_MTI, "0100", conf);
	 message.putISOField(mti);
	 Bitmap b0=new Bitmap(ISOField.F0_BITMAP0, conf);
	 message.putISOField(b0); // primary bitmap
	
	 Bitmap b1=new Bitmap(ISOField.F1_BITMAP1, conf);
	 b0.setBit(ISOField.F1_BITMAP1, true);
	 message.putISOField(b1); //secondary bitmap
	 
	 ISOField processing_code=new ISOField(ISOField.F3_PROC_CODE, "033000", conf);	 
         b0.setBit(ISOField.F3_PROC_CODE, true);
         message.putISOField(processing_code);
          
         ISOField amount=new ISOField(ISOField.F4_AMOUNT_TR /*F4_TR_AMOUNT*/, "250", conf);	// $2.50 
         b0.setBit(ISOField.F4_AMOUNT_TR /*F4_TR_AMOUNT*/, true);
         message.putISOField(amount);
         
         ISOField trdate=new ISOField(ISOField.F7_DATETIME_TR, "0529213059", conf); // date
         b0.setBit(ISOField.F7_DATETIME_TR, true);
         message.putISOField(trdate);
         
         ISOField stan=new ISOField(ISOField.F11_STAN, ""+j, conf); // system audit number
         b0.setBit(ISOField.F11_STAN, true);
         message.putISOField(stan);
         
         ISOField localtrtime=new ISOField(ISOField.F12_DATE_TIME_LTR /*F12_TIME_LTR*/, "213059", conf); // time local (21:30:59)
         b0.setBit(ISOField.F12_DATE_TIME_LTR /*F12_TIME_LTR*/, true);
         message.putISOField(localtrtime);
         
         ISOField localtrdate=new ISOField(ISOField.F13_DATE_EFF, "0529", conf); // date local (5/29)
         b0.setBit(ISOField.F13_DATE_EFF, true);
         message.putISOField(localtrdate);
         
         ISOField busdate=new ISOField(ISOField.F17_DATE_CAPTURE, "0530", conf); // business date (next day 5/30)
         b0.setBit(ISOField.F17_DATE_CAPTURE, true);
         message.putISOField(busdate);
         
         ISOField track2=new ISOField(ISOField.F35_TRACK2, "4443330000000012=0412000123000", conf); // track2
         b0.setBit(ISOField.F35_TRACK2, true);
         message.putISOField(track2);
         
         ISOField lcode=new ISOField(ISOField.F44_ADD_RESPDATA, "0", conf); // english
         b0.setBit(ISOField.F44_ADD_RESPDATA, true);
         message.putISOField(lcode);
         
         ISOField spdhh=new ISOField(ISOField.F48_ADD_DATA_PRIVATE, "900123456789012          010529213059FO00000000", conf); // by your spec
         b0.setBit(ISOField.F48_ADD_DATA_PRIVATE, true);
         message.putISOField(spdhh);

         ISOField poscondcode=new ISOField(ISOField.F60, "1311030", conf); // pos cond code
         b0.setBit(ISOField.F60, true);
         message.putISOField(poscondcode);

         ISOField cardtype=new ISOField(ISOField.F63, "C", conf); // credit card
         b0.setBit(ISOField.F63, true);
         message.putISOField(cardtype);
         
 
         ISOField optdata=new ISOField(ISOField.F127, "    MerSpec", conf); // optional data custom 
         b1.setBit(ISOField.F127, true); // this goes to second bitmap
         message.putISOField(optdata);
         

         // now let lib to format message (field length padding and everything
         // like that will happen internally in ISO8583 lib)
	byte[] data=null;
	try {
          data=isosdk.formatLLPlain(message);
         
         // now you got data that could be written to tcp/ip socket outpustream
         // in this example is use System.out
         if (debug) 
		 {System.out.print("The formatted message='"); 
          System.out.write(data);
          System.out.println("'");
          System.out.println();
		 }
         // in case of real use: someoutputstream.write(data);
	
	} catch (Exception e) { 
			System.out.println("There was error formatting message ");
          		e.printStackTrace(System.out);
          		}
       /// now parse back to objects   
	try {
	 // create a inputstream from formatted data and parse it back to objects
	 Message message2=new Message(isosdk.parseLLPlain(new InputStreamBuffer(data)));
	 //System.out.println("Message contents: "+message2);
	 //or lets print out all fields we will find
	 for (int i=-3; i<128; i++) 
	  { ISOField isf=(ISOField)message.getISOField(i);
	    if (isf!=null && debug) System.out.println("Found field "+i+"='"+isf.getStringValue()+"'");
	    }
	
	} catch (Exception e) { 
		System.out.println("There was error parsing message ");
		e.printStackTrace(System.out);
			}
	
	
	
	} // for n

	long end=System.currentTimeMillis();
	System.out.println(n+" cycles done in "+(end-start)+ " ms");
	
	} // main
	

} // isosample